==> Devel-LineTrace-0.1.11.tar.gz: Devel-LineTrace-0.1.11/lib/Devel/LineTrace.pm <==
package Devel::LineTrace;
$Devel::LineTrace::VERSION = '0.1.11';
use strict;
use warnings;

require 5.006;

package DB;
$DB::VERSION = '0.1.11';
my (%files);

sub BEGIN
{
    my $filename = $ENV{'PERL5DB_LT'} || "perl-line-traces.txt";
    open my $in_fh, "<", $filename
        or return;
    my $line;
    $line = <$in_fh>;
MAIN:
    while ($line)
    {
        chomp $line;
        if ( ( $line =~ /^\s+/ ) || ( $line =~ /^#/ ) )
        {
            $line = <$in_fh>;
            next MAIN;
        }
        $line =~ /^(.+):(\d+)$/;
        my $filename = $1;
        my $line_num = $2;
        my $callback = "";
    CALLBACK:
        while ( $line = <$in_fh> )
        {

            if ( $line =~ /^\s/ )
            {
                $callback .= $line;
            }
            else
            {
                last CALLBACK;
            }
        }
        $files{$filename}{$line_num} = $callback;
    }
    close($in_fh);

    return;
}

use vars qw(@saved $package $filename $line $usercontext);

sub DB
{
    local @saved = ( $@, $!, $^E, $,, $/, $\, $^W );
    local ( $package, $filename, $line ) = caller;
    local $usercontext = '($@, $!, $^E, $,, $/, $\, $^W) = @saved;'
        . "package $package;";    # this won't let them modify, alas
    if ( exists( $files{$filename}{$line} ) )
    {
        eval $usercontext . " " . $files{$filename}{$line};
    }
}

1;

__END__

=pod

=encoding UTF-8

=head1 VERSION

version 0.1.11

=head1 DESCRIPTION

This is a class that enables assigning Perl code callbacks to certain
lines in the original code B<without modifying it>.

To do so prepare a file with the following syntax:

    [source_filename]:[line]
        [CODE]
        [CODE]
        [CODE]
    [source_filename]:[line]
        [CODE]
        [CODE]
        [CODE]

Which will assign the [CODE] blocks to the filename and line combinations.
The [CODE] sections are indented from the main blocks. To temporarily cancel
a callback put a pound-sign (#) right at the start of the line (without
whitespace beforehand).

The location of the file should be specified by the PERL5DB_LT environment
variable (or else it defaults to C<perl-line-traces.txt>.)

Then invoke the perl interpreter like this:

    perl -d:LineTrace myprogram.pl

=head1 NAME

Devel::LineTrace - Apply traces to individual lines.

=head1 SYNPOSIS

    perl -d:LineTrace myscript.pl [args ...]

=head1 SEE ALSO

L<Devel::Trace>, L<Debug::Trace>

=head1 COPYRIGHT & LICENSE

Copyright 2011 by Shlomi Fish.

This program is distributed under the MIT (X11) License:
L<http://www.opensource.org/licenses/mit-license.php>

Permission is hereby granted, free of charge, to any person
obtaining a copy of this software and associated documentation
files (the "Software"), to deal in the Software without
restriction, including without limitation the rights to use,
copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the
Software is furnished to do so, subject to the following
conditions:

The above copyright notice and this permission notice shall be
included in all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
OTHER DEALINGS IN THE SOFTWARE.

=head1 AUTHORS

Shlomi Fish ( L<http://www.shlomifish.org/> ).

=for :stopwords cpan testmatrix url annocpan anno bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan

=head1 SUPPORT

=head2 Websites

The following websites have more information about this module, and may be of help to you. As always,
in addition to those websites please use your favorite search engine to discover more resources.

=over 4

=item *

MetaCPAN

A modern, open-source CPAN search engine, useful to view POD in HTML format.

L<https://metacpan.org/release/Devel-LineTrace>

=item *

Search CPAN

The default CPAN search engine, useful to view POD in HTML format.

L<http://search.cpan.org/dist/Devel-LineTrace>

=item *

RT: CPAN's Bug Tracker

The RT ( Request Tracker ) website is the default bug/issue tracking system for CPAN.

L<https://rt.cpan.org/Public/Dist/Display.html?Name=Devel-LineTrace>

=item *

AnnoCPAN

The AnnoCPAN is a website that allows community annotations of Perl module documentation.

L<http://annocpan.org/dist/Devel-LineTrace>

=item *

CPAN Ratings

The CPAN Ratings is a website that allows community ratings and reviews of Perl modules.

L<http://cpanratings.perl.org/d/Devel-LineTrace>

=item *

CPANTS

The CPANTS is a website that analyzes the Kwalitee ( code metrics ) of a distribution.

L<http://cpants.cpanauthors.org/dist/Devel-LineTrace>

=item *

CPAN Testers

The CPAN Testers is a network of smoke testers who run automated tests on uploaded CPAN distributions.

L<http://www.cpantesters.org/distro/D/Devel-LineTrace>

=item *

CPAN Testers Matrix

The CPAN Testers Matrix is a website that provides a visual overview of the test results for a distribution on various Perls/platforms.

L<http://matrix.cpantesters.org/?dist=Devel-LineTrace>

=item *

CPAN Testers Dependencies

The CPAN Testers Dependencies is a website that shows a chart of the test results of all dependencies for a distribution.

L<http://deps.cpantesters.org/?module=Devel::LineTrace>

=back

=head2 Bugs / Feature Requests

Please report any bugs or feature requests by email to C<bug-devel-linetrace at rt.cpan.org>, or through
the web interface at L<https://rt.cpan.org/Public/Bug/Report.html?Queue=Devel-LineTrace>. You will be automatically notified of any
progress on the request by the system.

=head2 Source Code

The code is open to the world, and available for you to hack on. Please feel free to browse it and play
with it, or whatever. If you want to contribute patches, please send me a diff or prod me to pull
from your repository :)

L<https://github.com/shlomif/perl-devel-linetrace>

  git clone git://github.com/shlomif/perl-devel-linetrace.git

=head1 AUTHOR

Shlomi Fish <shlomif@cpan.org>

=head1 BUGS

Please report any bugs or feature requests on the bugtracker website
L<https://github.com/shlomif/perl-devel-linetrace/issues>

When submitting a bug or request, please include a test-file or a
patch to an existing test-file that illustrates the bug or desired
feature.

=head1 COPYRIGHT AND LICENSE

This software is Copyright (c) 2003 by Shlomi Fish.

This is free software, licensed under:

  The MIT (X11) License

=cut

==> Devel-LineTrace-0.1.12.tar.gz: Devel-LineTrace-0.1.12/lib/Devel/LineTrace.pm <==
package Devel::LineTrace;
$Devel::LineTrace::VERSION = '0.1.12';
use strict;
use warnings;

require 5.006;

package DB;
$DB::VERSION = '0.1.12';
my (%files);

sub BEGIN
{
    my $filename = $ENV{'PERL5DB_LT'} || "perl-line-traces.txt";
    open my $in_fh, "<", $filename
        or return;
    my $line;
    $line = <$in_fh>;
MAIN:
    while ($line)
    {
        chomp $line;
        if ( ( $line =~ /^\s+/ ) || ( $line =~ /^#/ ) )
        {
            $line = <$in_fh>;
            next MAIN;
        }
        $line =~ /^(.+):(\d+)$/;
        my $filename = $1;
        my $line_num = $2;
        my $callback = "";
    CALLBACK:
        while ( $line = <$in_fh> )
        {

            if ( $line =~ /^\s/ )
            {
                $callback .= $line;
            }
            else
            {
                last CALLBACK;
            }
        }
        $files{$filename}{$line_num} = $callback;
    }
    close($in_fh);

    return;
}

use vars qw(@saved $package $filename $line $usercontext);

sub DB
{
    local @saved = ( $@, $!, $^E, $,, $/, $\, $^W );
    local ( $package, $filename, $line ) = caller;
    local $usercontext = '($@, $!, $^E, $,, $/, $\, $^W) = @saved;'
        . "package $package;";    # this won't let them modify, alas
    if ( exists( $files{$filename}{$line} ) )
    {
        eval $usercontext . " " . $files{$filename}{$line};
    }
}

1;

__END__

=pod

=encoding UTF-8

=head1 NAME

Devel::LineTrace - Apply traces to individual lines.

=head1 VERSION

version 0.1.12

=head1 DESCRIPTION

This is a class that enables assigning Perl code callbacks to certain
lines in the original code B<without modifying it>.

To do so prepare a file with the following syntax:

    [source_filename]:[line]
        [CODE]
        [CODE]
        [CODE]
    [source_filename]:[line]
        [CODE]
        [CODE]
        [CODE]

Which will assign the [CODE] blocks to the filename and line combinations.
The [CODE] sections are indented from the main blocks. To temporarily cancel
a callback put a pound-sign (#) right at the start of the line (without
whitespace beforehand).

The location of the file should be specified by the PERL5DB_LT environment
variable (or else it defaults to C<perl-line-traces.txt>.)

Then invoke the perl interpreter like this:

    perl -d:LineTrace myprogram.pl

=head1 SYNPOSIS

    perl -d:LineTrace myscript.pl [args ...]

=head1 SEE ALSO

L<Devel::Trace>, L<Debug::Trace>

=head1 COPYRIGHT & LICENSE

Copyright 2011 by Shlomi Fish.

This program is distributed under the MIT (X11) License:
L<http://www.opensource.org/licenses/mit-license.php>

Permission is hereby granted, free of charge, to any person
obtaining a copy of this software and associated documentation
files (the "Software"), to deal in the Software without
restriction, including without limitation the rights to use,
copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the
Software is furnished to do so, subject to the following
conditions:

The above copyright notice and this permission notice shall be
included in all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
OTHER DEALINGS IN THE SOFTWARE.

=head1 AUTHORS

Shlomi Fish ( L<http://www.shlomifish.org/> ).

=for :stopwords cpan testmatrix url bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan

=head1 SUPPORT

=head2 Websites

The following websites have more information about this module, and may be of help to you. As always,
in addition to those websites please use your favorite search engine to discover more resources.

=over 4

=item *

MetaCPAN

A modern, open-source CPAN search engine, useful to view POD in HTML format.

L<https://metacpan.org/release/Devel-LineTrace>

=item *

Search CPAN

The default CPAN search engine, useful to view POD in HTML format.

L<http://search.cpan.org/dist/Devel-LineTrace>

=item *

RT: CPAN's Bug Tracker

The RT ( Request Tracker ) website is the default bug/issue tracking system for CPAN.

L<https://rt.cpan.org/Public/Dist/Display.html?Name=Devel-LineTrace>

=item *

CPAN Ratings

The CPAN Ratings is a website that allows community ratings and reviews of Perl modules.

L<http://cpanratings.perl.org/d/Devel-LineTrace>

=item *

CPANTS

The CPANTS is a website that analyzes the Kwalitee ( code metrics ) of a distribution.

L<http://cpants.cpanauthors.org/dist/Devel-LineTrace>

=item *

CPAN Testers

The CPAN Testers is a network of smoke testers who run automated tests on uploaded CPAN distributions.

L<http://www.cpantesters.org/distro/D/Devel-LineTrace>

=item *

CPAN Testers Matrix

The CPAN Testers Matrix is a website that provides a visual overview of the test results for a distribution on various Perls/platforms.

L<http://matrix.cpantesters.org/?dist=Devel-LineTrace>

=item *

CPAN Testers Dependencies

The CPAN Testers Dependencies is a website that shows a chart of the test results of all dependencies for a distribution.

L<http://deps.cpantesters.org/?module=Devel::LineTrace>

=back

=head2 Bugs / Feature Requests

Please report any bugs or feature requests by email to C<bug-devel-linetrace at rt.cpan.org>, or through
the web interface at L<https://rt.cpan.org/Public/Bug/Report.html?Queue=Devel-LineTrace>. You will be automatically notified of any
progress on the request by the system.

=head2 Source Code

The code is open to the world, and available for you to hack on. Please feel free to browse it and play
with it, or whatever. If you want to contribute patches, please send me a diff or prod me to pull
from your repository :)

L<https://github.com/shlomif/perl-devel-linetrace>

  git clone git://github.com/shlomif/perl-devel-linetrace.git

=head1 AUTHOR

Shlomi Fish <shlomif@cpan.org>

=head1 BUGS

Please report any bugs or feature requests on the bugtracker website
L<https://github.com/shlomif/perl-devel-linetrace/issues>

When submitting a bug or request, please include a test-file or a
patch to an existing test-file that illustrates the bug or desired
feature.

=head1 COPYRIGHT AND LICENSE

This software is Copyright (c) 2003 by Shlomi Fish.

This is free software, licensed under:

  The MIT (X11) License

=cut
